mix project.gen.hotwire_native (project v1.0.18)
Sets up Turbo, Stimulus, bridge components, native app detection, path configuration endpoints, and conditional styling for Hotwire Native mobile apps.
Sets up Turbo, Stimulus, bridge components, native app detection, path configuration endpoints, and conditional styling for Hotwire Native mobile apps.